@@ -36,7 +36,9 @@ __all__ = (
     "ListNodesPaginatorName",
     "ListScramSecretsPaginatorName",
     "NodeTypeType",
+    "KafkaServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -68,6 +70,7 @@ ListKafkaVersionsPaginatorName = Literal["list_kafka_versions"]
 ListNodesPaginatorName = Literal["list_nodes"]
 ListScramSecretsPaginatorName = Literal["list_scram_secrets"]
 NodeTypeType = Literal["BROKER"]
+KafkaServiceName = Literal["kafka"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -99,6 +102,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -221,6 +225,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -369,6 +374,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "list_cluster_operations",
     "list_clusters",
