@@ -16,6 +16,7 @@ from datetime import datetime
 from typing import IO, Dict, List, Mapping, Sequence, Union
 
 from botocore.response import StreamingBody
+from typing_extensions import NotRequired
 
 from .literals import (
     ClientBrokerType,
@@ -197,200 +198,153 @@ BatchDisassociateScramSecretResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredBrokerEBSVolumeInfoTypeDef = TypedDict(
-    "_RequiredBrokerEBSVolumeInfoTypeDef",
+BrokerEBSVolumeInfoTypeDef = TypedDict(
+    "BrokerEBSVolumeInfoTypeDef",
     {
         "KafkaBrokerNodeId": str,
+        "ProvisionedThroughput": NotRequired["ProvisionedThroughputTypeDef"],
+        "VolumeSizeGB": NotRequired[int],
     },
 )
-_OptionalBrokerEBSVolumeInfoTypeDef = TypedDict(
-    "_OptionalBrokerEBSVolumeInfoTypeDef",
-    {
-        "ProvisionedThroughput": "ProvisionedThroughputTypeDef",
-        "VolumeSizeGB": int,
-    },
-    total=False,
-)
-
-
-class BrokerEBSVolumeInfoTypeDef(
-    _RequiredBrokerEBSVolumeInfoTypeDef, _OptionalBrokerEBSVolumeInfoTypeDef
-):
-    pass
-
 
 BrokerLogsTypeDef = TypedDict(
     "BrokerLogsTypeDef",
     {
-        "CloudWatchLogs": "CloudWatchLogsTypeDef",
-        "Firehose": "FirehoseTypeDef",
-        "S3": "S3TypeDef",
+        "CloudWatchLogs": NotRequired["CloudWatchLogsTypeDef"],
+        "Firehose": NotRequired["FirehoseTypeDef"],
+        "S3": NotRequired["S3TypeDef"],
     },
-    total=False,
 )
 
-_RequiredBrokerNodeGroupInfoTypeDef = TypedDict(
-    "_RequiredBrokerNodeGroupInfoTypeDef",
+BrokerNodeGroupInfoTypeDef = TypedDict(
+    "BrokerNodeGroupInfoTypeDef",
     {
         "ClientSubnets": Sequence[str],
         "InstanceType": str,
+        "BrokerAZDistribution": NotRequired[Literal["DEFAULT"]],
+        "SecurityGroups": NotRequired[Sequence[str]],
+        "StorageInfo": NotRequired["StorageInfoTypeDef"],
+        "ConnectivityInfo": NotRequired["ConnectivityInfoTypeDef"],
     },
 )
-_OptionalBrokerNodeGroupInfoTypeDef = TypedDict(
-    "_OptionalBrokerNodeGroupInfoTypeDef",
-    {
-        "BrokerAZDistribution": Literal["DEFAULT"],
-        "SecurityGroups": Sequence[str],
-        "StorageInfo": "StorageInfoTypeDef",
-        "ConnectivityInfo": "ConnectivityInfoTypeDef",
-    },
-    total=False,
-)
-
-
-class BrokerNodeGroupInfoTypeDef(
-    _RequiredBrokerNodeGroupInfoTypeDef, _OptionalBrokerNodeGroupInfoTypeDef
-):
-    pass
-
 
 BrokerNodeInfoTypeDef = TypedDict(
     "BrokerNodeInfoTypeDef",
     {
-        "AttachedENIId": str,
-        "BrokerId": float,
-        "ClientSubnet": str,
-        "ClientVpcIpAddress": str,
-        "CurrentBrokerSoftwareInfo": "BrokerSoftwareInfoTypeDef",
-        "Endpoints": List[str],
+        "AttachedENIId": NotRequired[str],
+        "BrokerId": NotRequired[float],
+        "ClientSubnet": NotRequired[str],
+        "ClientVpcIpAddress": NotRequired[str],
+        "CurrentBrokerSoftwareInfo": NotRequired["BrokerSoftwareInfoTypeDef"],
+        "Endpoints": NotRequired[List[str]],
     },
-    total=False,
 )
 
 BrokerSoftwareInfoTypeDef = TypedDict(
     "BrokerSoftwareInfoTypeDef",
     {
-        "ConfigurationArn": str,
-        "ConfigurationRevision": int,
-        "KafkaVersion": str,
+        "ConfigurationArn": NotRequired[str],
+        "ConfigurationRevision": NotRequired[int],
+        "KafkaVersion": NotRequired[str],
     },
-    total=False,
 )
 
 ClientAuthenticationTypeDef = TypedDict(
     "ClientAuthenticationTypeDef",
     {
-        "Sasl": "SaslTypeDef",
-        "Tls": "TlsTypeDef",
-        "Unauthenticated": "UnauthenticatedTypeDef",
+        "Sasl": NotRequired["SaslTypeDef"],
+        "Tls": NotRequired["TlsTypeDef"],
+        "Unauthenticated": NotRequired["UnauthenticatedTypeDef"],
     },
-    total=False,
 )
 
-_RequiredCloudWatchLogsTypeDef = TypedDict(
-    "_RequiredCloudWatchLogsTypeDef",
+CloudWatchLogsTypeDef = TypedDict(
+    "CloudWatchLogsTypeDef",
     {
         "Enabled": bool,
+        "LogGroup": NotRequired[str],
     },
 )
-_OptionalCloudWatchLogsTypeDef = TypedDict(
-    "_OptionalCloudWatchLogsTypeDef",
-    {
-        "LogGroup": str,
-    },
-    total=False,
-)
-
-
-class CloudWatchLogsTypeDef(_RequiredCloudWatchLogsTypeDef, _OptionalCloudWatchLogsTypeDef):
-    pass
-
 
 ClusterInfoTypeDef = TypedDict(
     "ClusterInfoTypeDef",
     {
-        "ActiveOperationArn": str,
-        "BrokerNodeGroupInfo": "BrokerNodeGroupInfoTypeDef",
-        "ClientAuthentication": "ClientAuthenticationTypeDef",
-        "ClusterArn": str,
-        "ClusterName": str,
-        "CreationTime": datetime,
-        "CurrentBrokerSoftwareInfo": "BrokerSoftwareInfoTypeDef",
-        "CurrentVersion": str,
-        "EncryptionInfo": "EncryptionInfoTypeDef",
-        "EnhancedMonitoring": EnhancedMonitoringType,
-        "OpenMonitoring": "OpenMonitoringTypeDef",
-        "LoggingInfo": "LoggingInfoTypeDef",
-        "NumberOfBrokerNodes": int,
-        "State": ClusterStateType,
-        "StateInfo": "StateInfoTypeDef",
-        "Tags": Dict[str, str],
-        "ZookeeperConnectString": str,
-        "ZookeeperConnectStringTls": str,
+        "ActiveOperationArn": NotRequired[str],
+        "BrokerNodeGroupInfo": NotRequired["BrokerNodeGroupInfoTypeDef"],
+        "ClientAuthentication": NotRequired["ClientAuthenticationTypeDef"],
+        "ClusterArn": NotRequired[str],
+        "ClusterName": NotRequired[str],
+        "CreationTime": NotRequired[datetime],
+        "CurrentBrokerSoftwareInfo": NotRequired["BrokerSoftwareInfoTypeDef"],
+        "CurrentVersion": NotRequired[str],
+        "EncryptionInfo": NotRequired["EncryptionInfoTypeDef"],
+        "EnhancedMonitoring": NotRequired[EnhancedMonitoringType],
+        "OpenMonitoring": NotRequired["OpenMonitoringTypeDef"],
+        "LoggingInfo": NotRequired["LoggingInfoTypeDef"],
+        "NumberOfBrokerNodes": NotRequired[int],
+        "State": NotRequired[ClusterStateType],
+        "StateInfo": NotRequired["StateInfoTypeDef"],
+        "Tags": NotRequired[Dict[str, str]],
+        "ZookeeperConnectString": NotRequired[str],
+        "ZookeeperConnectStringTls": NotRequired[str],
     },
-    total=False,
 )
 
 ClusterOperationInfoTypeDef = TypedDict(
     "ClusterOperationInfoTypeDef",
     {
-        "ClientRequestId": str,
-        "ClusterArn": str,
-        "CreationTime": datetime,
-        "EndTime": datetime,
-        "ErrorInfo": "ErrorInfoTypeDef",
-        "OperationArn": str,
-        "OperationState": str,
-        "OperationSteps": List["ClusterOperationStepTypeDef"],
-        "OperationType": str,
-        "SourceClusterInfo": "MutableClusterInfoTypeDef",
-        "TargetClusterInfo": "MutableClusterInfoTypeDef",
+        "ClientRequestId": NotRequired[str],
+        "ClusterArn": NotRequired[str],
+        "CreationTime": NotRequired[datetime],
+        "EndTime": NotRequired[datetime],
+        "ErrorInfo": NotRequired["ErrorInfoTypeDef"],
+        "OperationArn": NotRequired[str],
+        "OperationState": NotRequired[str],
+        "OperationSteps": NotRequired[List["ClusterOperationStepTypeDef"]],
+        "OperationType": NotRequired[str],
+        "SourceClusterInfo": NotRequired["MutableClusterInfoTypeDef"],
+        "TargetClusterInfo": NotRequired["MutableClusterInfoTypeDef"],
     },
-    total=False,
 )
 
 ClusterOperationStepInfoTypeDef = TypedDict(
     "ClusterOperationStepInfoTypeDef",
     {
-        "StepStatus": str,
+        "StepStatus": NotRequired[str],
     },
-    total=False,
 )
 
 ClusterOperationStepTypeDef = TypedDict(
     "ClusterOperationStepTypeDef",
     {
-        "StepInfo": "ClusterOperationStepInfoTypeDef",
-        "StepName": str,
+        "StepInfo": NotRequired["ClusterOperationStepInfoTypeDef"],
+        "StepName": NotRequired[str],
     },
-    total=False,
 )
 
 ClusterTypeDef = TypedDict(
     "ClusterTypeDef",
     {
-        "ActiveOperationArn": str,
-        "ClusterType": ClusterTypeType,
-        "ClusterArn": str,
-        "ClusterName": str,
-        "CreationTime": datetime,
-        "CurrentVersion": str,
-        "State": ClusterStateType,
-        "StateInfo": "StateInfoTypeDef",
-        "Tags": Dict[str, str],
-        "Provisioned": "ProvisionedTypeDef",
-        "Serverless": "ServerlessTypeDef",
+        "ActiveOperationArn": NotRequired[str],
+        "ClusterType": NotRequired[ClusterTypeType],
+        "ClusterArn": NotRequired[str],
+        "ClusterName": NotRequired[str],
+        "CreationTime": NotRequired[datetime],
+        "CurrentVersion": NotRequired[str],
+        "State": NotRequired[ClusterStateType],
+        "StateInfo": NotRequired["StateInfoTypeDef"],
+        "Tags": NotRequired[Dict[str, str]],
+        "Provisioned": NotRequired["ProvisionedTypeDef"],
+        "Serverless": NotRequired["ServerlessTypeDef"],
     },
-    total=False,
 )
 
 CompatibleKafkaVersionTypeDef = TypedDict(
     "CompatibleKafkaVersionTypeDef",
     {
-        "SourceVersion": str,
-        "TargetVersions": List[str],
+        "SourceVersion": NotRequired[str],
+        "TargetVersions": NotRequired[List[str]],
     },
-    total=False,
 )
 
 ConfigurationInfoTypeDef = TypedDict(
@@ -401,27 +355,14 @@ ConfigurationInfoTypeDef = TypedDict(
     },
 )
 
-_RequiredConfigurationRevisionTypeDef = TypedDict(
-    "_RequiredConfigurationRevisionTypeDef",
+ConfigurationRevisionTypeDef = TypedDict(
+    "ConfigurationRevisionTypeDef",
     {
         "CreationTime": datetime,
         "Revision": int,
+        "Description": NotRequired[str],
     },
 )
-_OptionalConfigurationRevisionTypeDef = TypedDict(
-    "_OptionalConfigurationRevisionTypeDef",
-    {
-        "Description": str,
-    },
-    total=False,
-)
-
-
-class ConfigurationRevisionTypeDef(
-    _RequiredConfigurationRevisionTypeDef, _OptionalConfigurationRevisionTypeDef
-):
-    pass
-
 
 ConfigurationTypeDef = TypedDict(
     "ConfigurationTypeDef",
@@ -439,40 +380,26 @@ ConfigurationTypeDef = TypedDict(
 ConnectivityInfoTypeDef = TypedDict(
     "ConnectivityInfoTypeDef",
     {
-        "PublicAccess": "PublicAccessTypeDef",
+        "PublicAccess": NotRequired["PublicAccessTypeDef"],
     },
-    total=False,
 )
 
-_RequiredCreateClusterRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateClusterRequestRequestTypeDef",
+CreateClusterRequestRequestTypeDef = TypedDict(
+    "CreateClusterRequestRequestTypeDef",
     {
         "BrokerNodeGroupInfo": "BrokerNodeGroupInfoTypeDef",
         "ClusterName": str,
         "KafkaVersion": str,
         "NumberOfBrokerNodes": int,
+        "ClientAuthentication": NotRequired["ClientAuthenticationTypeDef"],
+        "ConfigurationInfo": NotRequired["ConfigurationInfoTypeDef"],
+        "EncryptionInfo": NotRequired["EncryptionInfoTypeDef"],
+        "EnhancedMonitoring": NotRequired[EnhancedMonitoringType],
+        "OpenMonitoring": NotRequired["OpenMonitoringInfoTypeDef"],
+        "LoggingInfo": NotRequired["LoggingInfoTypeDef"],
+        "Tags": NotRequired[Mapping[str, str]],
     },
 )
-_OptionalCreateClusterRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateClusterRequestRequestTypeDef",
-    {
-        "ClientAuthentication": "ClientAuthenticationTypeDef",
-        "ConfigurationInfo": "ConfigurationInfoTypeDef",
-        "EncryptionInfo": "EncryptionInfoTypeDef",
-        "EnhancedMonitoring": EnhancedMonitoringType,
-        "OpenMonitoring": "OpenMonitoringInfoTypeDef",
-        "LoggingInfo": "LoggingInfoTypeDef",
-        "Tags": Mapping[str, str],
-    },
-    total=False,
-)
-
-
-class CreateClusterRequestRequestTypeDef(
-    _RequiredCreateClusterRequestRequestTypeDef, _OptionalCreateClusterRequestRequestTypeDef
-):
-    pass
-
 
 CreateClusterResponseTypeDef = TypedDict(
     "CreateClusterResponseTypeDef",
@@ -484,28 +411,15 @@ CreateClusterResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateClusterV2RequestRequestTypeDef = TypedDict(
-    "_RequiredCreateClusterV2RequestRequestTypeDef",
+CreateClusterV2RequestRequestTypeDef = TypedDict(
+    "CreateClusterV2RequestRequestTypeDef",
     {
         "ClusterName": str,
+        "Tags": NotRequired[Mapping[str, str]],
+        "Provisioned": NotRequired["ProvisionedRequestTypeDef"],
+        "Serverless": NotRequired["ServerlessRequestTypeDef"],
     },
 )
-_OptionalCreateClusterV2RequestRequestTypeDef = TypedDict(
-    "_OptionalCreateClusterV2RequestRequestTypeDef",
-    {
-        "Tags": Mapping[str, str],
-        "Provisioned": "ProvisionedRequestTypeDef",
-        "Serverless": "ServerlessRequestTypeDef",
-    },
-    total=False,
-)
-
-
-class CreateClusterV2RequestRequestTypeDef(
-    _RequiredCreateClusterV2RequestRequestTypeDef, _OptionalCreateClusterV2RequestRequestTypeDef
-):
-    pass
-
 
 CreateClusterV2ResponseTypeDef = TypedDict(
     "CreateClusterV2ResponseTypeDef",
@@ -518,29 +432,15 @@ CreateClusterV2ResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateConfigurationRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateConfigurationRequestRequestTypeDef",
+CreateConfigurationRequestRequestTypeDef = TypedDict(
+    "CreateConfigurationRequestRequestTypeDef",
     {
         "Name": str,
         "ServerProperties": Union[bytes, IO[bytes], StreamingBody],
+        "Description": NotRequired[str],
+        "KafkaVersions": NotRequired[Sequence[str]],
     },
 )
-_OptionalCreateConfigurationRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateConfigurationRequestRequestTypeDef",
-    {
-        "Description": str,
-        "KafkaVersions": Sequence[str],
-    },
-    total=False,
-)
-
-
-class CreateConfigurationRequestRequestTypeDef(
-    _RequiredCreateConfigurationRequestRequestTypeDef,
-    _OptionalCreateConfigurationRequestRequestTypeDef,
-):
-    pass
-
 
 CreateConfigurationResponseTypeDef = TypedDict(
     "CreateConfigurationResponseTypeDef",
@@ -554,26 +454,13 @@ CreateConfigurationResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredDeleteClusterRequestRequestTypeDef = TypedDict(
-    "_RequiredDeleteClusterRequestRequestTypeDef",
+DeleteClusterRequestRequestTypeDef = TypedDict(
+    "DeleteClusterRequestRequestTypeDef",
     {
         "ClusterArn": str,
+        "CurrentVersion": NotRequired[str],
     },
 )
-_OptionalDeleteClusterRequestRequestTypeDef = TypedDict(
-    "_OptionalDeleteClusterRequestRequestTypeDef",
-    {
-        "CurrentVersion": str,
-    },
-    total=False,
-)
-
-
-class DeleteClusterRequestRequestTypeDef(
-    _RequiredDeleteClusterRequestRequestTypeDef, _OptionalDeleteClusterRequestRequestTypeDef
-):
-    pass
-
 
 DeleteClusterResponseTypeDef = TypedDict(
     "DeleteClusterResponseTypeDef",
@@ -689,10 +576,9 @@ DescribeConfigurationRevisionResponseTypeDef = TypedDict(
 EBSStorageInfoTypeDef = TypedDict(
     "EBSStorageInfoTypeDef",
     {
-        "ProvisionedThroughput": "ProvisionedThroughputTypeDef",
-        "VolumeSize": int,
+        "ProvisionedThroughput": NotRequired["ProvisionedThroughputTypeDef"],
+        "VolumeSize": NotRequired[int],
     },
-    total=False,
 )
 
 EncryptionAtRestTypeDef = TypedDict(
@@ -705,48 +591,34 @@ EncryptionAtRestTypeDef = TypedDict(
 EncryptionInTransitTypeDef = TypedDict(
     "EncryptionInTransitTypeDef",
     {
-        "ClientBroker": ClientBrokerType,
-        "InCluster": bool,
+        "ClientBroker": NotRequired[ClientBrokerType],
+        "InCluster": NotRequired[bool],
     },
-    total=False,
 )
 
 EncryptionInfoTypeDef = TypedDict(
     "EncryptionInfoTypeDef",
     {
-        "EncryptionAtRest": "EncryptionAtRestTypeDef",
-        "EncryptionInTransit": "EncryptionInTransitTypeDef",
+        "EncryptionAtRest": NotRequired["EncryptionAtRestTypeDef"],
+        "EncryptionInTransit": NotRequired["EncryptionInTransitTypeDef"],
     },
-    total=False,
 )
 
 ErrorInfoTypeDef = TypedDict(
     "ErrorInfoTypeDef",
     {
-        "ErrorCode": str,
-        "ErrorString": str,
+        "ErrorCode": NotRequired[str],
+        "ErrorString": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredFirehoseTypeDef = TypedDict(
-    "_RequiredFirehoseTypeDef",
+FirehoseTypeDef = TypedDict(
+    "FirehoseTypeDef",
     {
         "Enabled": bool,
+        "DeliveryStream": NotRequired[str],
     },
 )
-_OptionalFirehoseTypeDef = TypedDict(
-    "_OptionalFirehoseTypeDef",
-    {
-        "DeliveryStream": str,
-    },
-    total=False,
-)
-
-
-class FirehoseTypeDef(_RequiredFirehoseTypeDef, _OptionalFirehoseTypeDef):
-    pass
-
 
 GetBootstrapBrokersRequestRequestTypeDef = TypedDict(
     "GetBootstrapBrokersRequestRequestTypeDef",
@@ -772,9 +644,8 @@ GetBootstrapBrokersResponseTypeDef = TypedDict(
 GetCompatibleKafkaVersionsRequestRequestTypeDef = TypedDict(
     "GetCompatibleKafkaVersionsRequestRequestTypeDef",
     {
-        "ClusterArn": str,
+        "ClusterArn": NotRequired[str],
     },
-    total=False,
 )
 
 GetCompatibleKafkaVersionsResponseTypeDef = TypedDict(
@@ -788,9 +659,8 @@ GetCompatibleKafkaVersionsResponseTypeDef = TypedDict(
 IamTypeDef = TypedDict(
     "IamTypeDef",
     {
-        "Enabled": bool,
+        "Enabled": NotRequired[bool],
     },
-    total=False,
 )
 
 JmxExporterInfoTypeDef = TypedDict(
@@ -810,34 +680,19 @@ JmxExporterTypeDef = TypedDict(
 KafkaVersionTypeDef = TypedDict(
     "KafkaVersionTypeDef",
     {
-        "Version": str,
-        "Status": KafkaVersionStatusType,
+        "Version": NotRequired[str],
+        "Status": NotRequired[KafkaVersionStatusType],
     },
-    total=False,
 )
 
-_RequiredListClusterOperationsRequestRequestTypeDef = TypedDict(
-    "_RequiredListClusterOperationsRequestRequestTypeDef",
+ListClusterOperationsRequestRequestTypeDef = TypedDict(
+    "ListClusterOperationsRequestRequestTypeDef",
     {
         "ClusterArn": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListClusterOperationsRequestRequestTypeDef = TypedDict(
-    "_OptionalListClusterOperationsRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListClusterOperationsRequestRequestTypeDef(
-    _RequiredListClusterOperationsRequestRequestTypeDef,
-    _OptionalListClusterOperationsRequestRequestTypeDef,
-):
-    pass
-
 
 ListClusterOperationsResponseTypeDef = TypedDict(
     "ListClusterOperationsResponseTypeDef",
@@ -851,11 +706,10 @@ ListClusterOperationsResponseTypeDef = TypedDict(
 ListClustersRequestRequestTypeDef = TypedDict(
     "ListClustersRequestRequestTypeDef",
     {
-        "ClusterNameFilter": str,
-        "MaxResults": int,
-        "NextToken": str,
+        "ClusterNameFilter": NotRequired[str],
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListClustersResponseTypeDef = TypedDict(
@@ -870,12 +724,11 @@ ListClustersResponseTypeDef = TypedDict(
 ListClustersV2RequestRequestTypeDef = TypedDict(
     "ListClustersV2RequestRequestTypeDef",
     {
-        "ClusterNameFilter": str,
-        "ClusterTypeFilter": str,
-        "MaxResults": int,
-        "NextToken": str,
+        "ClusterNameFilter": NotRequired[str],
+        "ClusterTypeFilter": NotRequired[str],
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListClustersV2ResponseTypeDef = TypedDict(
@@ -887,28 +740,14 @@ ListClustersV2ResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListConfigurationRevisionsRequestRequestTypeDef = TypedDict(
-    "_RequiredListConfigurationRevisionsRequestRequestTypeDef",
+ListConfigurationRevisionsRequestRequestTypeDef = TypedDict(
+    "ListConfigurationRevisionsRequestRequestTypeDef",
     {
         "Arn": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListConfigurationRevisionsRequestRequestTypeDef = TypedDict(
-    "_OptionalListConfigurationRevisionsRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListConfigurationRevisionsRequestRequestTypeDef(
-    _RequiredListConfigurationRevisionsRequestRequestTypeDef,
-    _OptionalListConfigurationRevisionsRequestRequestTypeDef,
-):
-    pass
-
 
 ListConfigurationRevisionsResponseTypeDef = TypedDict(
     "ListConfigurationRevisionsResponseTypeDef",
@@ -922,10 +761,9 @@ ListConfigurationRevisionsResponseTypeDef = TypedDict(
 ListConfigurationsRequestRequestTypeDef = TypedDict(
     "ListConfigurationsRequestRequestTypeDef",
     {
-        "MaxResults": int,
-        "NextToken": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListConfigurationsResponseTypeDef = TypedDict(
@@ -940,10 +778,9 @@ ListConfigurationsResponseTypeDef = TypedDict(
 ListKafkaVersionsRequestRequestTypeDef = TypedDict(
     "ListKafkaVersionsRequestRequestTypeDef",
     {
-        "MaxResults": int,
-        "NextToken": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListKafkaVersionsResponseTypeDef = TypedDict(
@@ -955,27 +792,14 @@ ListKafkaVersionsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListNodesRequestRequestTypeDef = TypedDict(
-    "_RequiredListNodesRequestRequestTypeDef",
+ListNodesRequestRequestTypeDef = TypedDict(
+    "ListNodesRequestRequestTypeDef",
     {
         "ClusterArn": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListNodesRequestRequestTypeDef = TypedDict(
-    "_OptionalListNodesRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListNodesRequestRequestTypeDef(
-    _RequiredListNodesRequestRequestTypeDef, _OptionalListNodesRequestRequestTypeDef
-):
-    pass
-
 
 ListNodesResponseTypeDef = TypedDict(
     "ListNodesResponseTypeDef",
@@ -986,27 +810,14 @@ ListNodesResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListScramSecretsRequestRequestTypeDef = TypedDict(
-    "_RequiredListScramSecretsRequestRequestTypeDef",
+ListScramSecretsRequestRequestTypeDef = TypedDict(
+    "ListScramSecretsRequestRequestTypeDef",
     {
         "ClusterArn": str,
+        "MaxResults": NotRequired[int],
+        "NextToken": NotRequired[str],
     },
 )
-_OptionalListScramSecretsRequestRequestTypeDef = TypedDict(
-    "_OptionalListScramSecretsRequestRequestTypeDef",
-    {
-        "MaxResults": int,
-        "NextToken": str,
-    },
-    total=False,
-)
-
-
-class ListScramSecretsRequestRequestTypeDef(
-    _RequiredListScramSecretsRequestRequestTypeDef, _OptionalListScramSecretsRequestRequestTypeDef
-):
-    pass
-
 
 ListScramSecretsResponseTypeDef = TypedDict(
     "ListScramSecretsResponseTypeDef",
@@ -1042,19 +853,18 @@ LoggingInfoTypeDef = TypedDict(
 MutableClusterInfoTypeDef = TypedDict(
     "MutableClusterInfoTypeDef",
     {
-        "BrokerEBSVolumeInfo": List["BrokerEBSVolumeInfoTypeDef"],
-        "ConfigurationInfo": "ConfigurationInfoTypeDef",
-        "NumberOfBrokerNodes": int,
-        "EnhancedMonitoring": EnhancedMonitoringType,
-        "OpenMonitoring": "OpenMonitoringTypeDef",
-        "KafkaVersion": str,
-        "LoggingInfo": "LoggingInfoTypeDef",
-        "InstanceType": str,
-        "ClientAuthentication": "ClientAuthenticationTypeDef",
-        "EncryptionInfo": "EncryptionInfoTypeDef",
-        "ConnectivityInfo": "ConnectivityInfoTypeDef",
+        "BrokerEBSVolumeInfo": NotRequired[List["BrokerEBSVolumeInfoTypeDef"]],
+        "ConfigurationInfo": NotRequired["ConfigurationInfoTypeDef"],
+        "NumberOfBrokerNodes": NotRequired[int],
+        "EnhancedMonitoring": NotRequired[EnhancedMonitoringType],
+        "OpenMonitoring": NotRequired["OpenMonitoringTypeDef"],
+        "KafkaVersion": NotRequired[str],
+        "LoggingInfo": NotRequired["LoggingInfoTypeDef"],
+        "InstanceType": NotRequired[str],
+        "ClientAuthentication": NotRequired["ClientAuthenticationTypeDef"],
+        "EncryptionInfo": NotRequired["EncryptionInfoTypeDef"],
+        "ConnectivityInfo": NotRequired["ConnectivityInfoTypeDef"],
     },
-    total=False,
 )
 
 NodeExporterInfoTypeDef = TypedDict(
@@ -1074,14 +884,13 @@ NodeExporterTypeDef = TypedDict(
 NodeInfoTypeDef = TypedDict(
     "NodeInfoTypeDef",
     {
-        "AddedToClusterTime": str,
-        "BrokerNodeInfo": "BrokerNodeInfoTypeDef",
-        "InstanceType": str,
-        "NodeARN": str,
-        "NodeType": Literal["BROKER"],
-        "ZookeeperNodeInfo": "ZookeeperNodeInfoTypeDef",
+        "AddedToClusterTime": NotRequired[str],
+        "BrokerNodeInfo": NotRequired["BrokerNodeInfoTypeDef"],
+        "InstanceType": NotRequired[str],
+        "NodeARN": NotRequired[str],
+        "NodeType": NotRequired[Literal["BROKER"]],
+        "ZookeeperNodeInfo": NotRequired["ZookeeperNodeInfoTypeDef"],
     },
-    total=False,
 )
 
 OpenMonitoringInfoTypeDef = TypedDict(
@@ -1101,101 +910,72 @@ OpenMonitoringTypeDef = TypedDict(
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "MaxItems": NotRequired[int],
+        "PageSize": NotRequired[int],
+        "StartingToken": NotRequired[str],
     },
-    total=False,
 )
 
 PrometheusInfoTypeDef = TypedDict(
     "PrometheusInfoTypeDef",
     {
-        "JmxExporter": "JmxExporterInfoTypeDef",
-        "NodeExporter": "NodeExporterInfoTypeDef",
+        "JmxExporter": NotRequired["JmxExporterInfoTypeDef"],
+        "NodeExporter": NotRequired["NodeExporterInfoTypeDef"],
     },
-    total=False,
 )
 
 PrometheusTypeDef = TypedDict(
     "PrometheusTypeDef",
     {
-        "JmxExporter": "JmxExporterTypeDef",
-        "NodeExporter": "NodeExporterTypeDef",
+        "JmxExporter": NotRequired["JmxExporterTypeDef"],
+        "NodeExporter": NotRequired["NodeExporterTypeDef"],
     },
-    total=False,
 )
 
-_RequiredProvisionedRequestTypeDef = TypedDict(
-    "_RequiredProvisionedRequestTypeDef",
+ProvisionedRequestTypeDef = TypedDict(
+    "ProvisionedRequestTypeDef",
     {
         "BrokerNodeGroupInfo": "BrokerNodeGroupInfoTypeDef",
         "KafkaVersion": str,
         "NumberOfBrokerNodes": int,
+        "ClientAuthentication": NotRequired["ClientAuthenticationTypeDef"],
+        "ConfigurationInfo": NotRequired["ConfigurationInfoTypeDef"],
+        "EncryptionInfo": NotRequired["EncryptionInfoTypeDef"],
+        "EnhancedMonitoring": NotRequired[EnhancedMonitoringType],
+        "OpenMonitoring": NotRequired["OpenMonitoringInfoTypeDef"],
+        "LoggingInfo": NotRequired["LoggingInfoTypeDef"],
     },
 )
-_OptionalProvisionedRequestTypeDef = TypedDict(
-    "_OptionalProvisionedRequestTypeDef",
-    {
-        "ClientAuthentication": "ClientAuthenticationTypeDef",
-        "ConfigurationInfo": "ConfigurationInfoTypeDef",
-        "EncryptionInfo": "EncryptionInfoTypeDef",
-        "EnhancedMonitoring": EnhancedMonitoringType,
-        "OpenMonitoring": "OpenMonitoringInfoTypeDef",
-        "LoggingInfo": "LoggingInfoTypeDef",
-    },
-    total=False,
-)
-
-
-class ProvisionedRequestTypeDef(
-    _RequiredProvisionedRequestTypeDef, _OptionalProvisionedRequestTypeDef
-):
-    pass
-
 
 ProvisionedThroughputTypeDef = TypedDict(
     "ProvisionedThroughputTypeDef",
     {
-        "Enabled": bool,
-        "VolumeThroughput": int,
+        "Enabled": NotRequired[bool],
+        "VolumeThroughput": NotRequired[int],
     },
-    total=False,
 )
 
-_RequiredProvisionedTypeDef = TypedDict(
-    "_RequiredProvisionedTypeDef",
+ProvisionedTypeDef = TypedDict(
+    "ProvisionedTypeDef",
     {
         "BrokerNodeGroupInfo": "BrokerNodeGroupInfoTypeDef",
         "NumberOfBrokerNodes": int,
+        "CurrentBrokerSoftwareInfo": NotRequired["BrokerSoftwareInfoTypeDef"],
+        "ClientAuthentication": NotRequired["ClientAuthenticationTypeDef"],
+        "EncryptionInfo": NotRequired["EncryptionInfoTypeDef"],
+        "EnhancedMonitoring": NotRequired[EnhancedMonitoringType],
+        "OpenMonitoring": NotRequired["OpenMonitoringInfoTypeDef"],
+        "LoggingInfo": NotRequired["LoggingInfoTypeDef"],
+        "ZookeeperConnectString": NotRequired[str],
+        "ZookeeperConnectStringTls": NotRequired[str],
     },
 )
-_OptionalProvisionedTypeDef = TypedDict(
-    "_OptionalProvisionedTypeDef",
-    {
-        "CurrentBrokerSoftwareInfo": "BrokerSoftwareInfoTypeDef",
-        "ClientAuthentication": "ClientAuthenticationTypeDef",
-        "EncryptionInfo": "EncryptionInfoTypeDef",
-        "EnhancedMonitoring": EnhancedMonitoringType,
-        "OpenMonitoring": "OpenMonitoringInfoTypeDef",
-        "LoggingInfo": "LoggingInfoTypeDef",
-        "ZookeeperConnectString": str,
-        "ZookeeperConnectStringTls": str,
-    },
-    total=False,
-)
-
-
-class ProvisionedTypeDef(_RequiredProvisionedTypeDef, _OptionalProvisionedTypeDef):
-    pass
-
 
 PublicAccessTypeDef = TypedDict(
     "PublicAccessTypeDef",
     {
-        "Type": str,
+        "Type": NotRequired[str],
     },
-    total=False,
 )
 
 RebootBrokerRequestRequestTypeDef = TypedDict(
@@ -1226,114 +1006,73 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-_RequiredS3TypeDef = TypedDict(
-    "_RequiredS3TypeDef",
+S3TypeDef = TypedDict(
+    "S3TypeDef",
     {
         "Enabled": bool,
+        "Bucket": NotRequired[str],
+        "Prefix": NotRequired[str],
     },
 )
-_OptionalS3TypeDef = TypedDict(
-    "_OptionalS3TypeDef",
-    {
-        "Bucket": str,
-        "Prefix": str,
-    },
-    total=False,
-)
-
-
-class S3TypeDef(_RequiredS3TypeDef, _OptionalS3TypeDef):
-    pass
-
 
 SaslTypeDef = TypedDict(
     "SaslTypeDef",
     {
-        "Scram": "ScramTypeDef",
-        "Iam": "IamTypeDef",
+        "Scram": NotRequired["ScramTypeDef"],
+        "Iam": NotRequired["IamTypeDef"],
     },
-    total=False,
 )
 
 ScramTypeDef = TypedDict(
     "ScramTypeDef",
     {
-        "Enabled": bool,
+        "Enabled": NotRequired[bool],
     },
-    total=False,
 )
 
 ServerlessClientAuthenticationTypeDef = TypedDict(
     "ServerlessClientAuthenticationTypeDef",
     {
-        "Sasl": "ServerlessSaslTypeDef",
+        "Sasl": NotRequired["ServerlessSaslTypeDef"],
     },
-    total=False,
 )
 
-_RequiredServerlessRequestTypeDef = TypedDict(
-    "_RequiredServerlessRequestTypeDef",
+ServerlessRequestTypeDef = TypedDict(
+    "ServerlessRequestTypeDef",
     {
         "VpcConfigs": Sequence["VpcConfigTypeDef"],
+        "ClientAuthentication": NotRequired["ServerlessClientAuthenticationTypeDef"],
     },
 )
-_OptionalServerlessRequestTypeDef = TypedDict(
-    "_OptionalServerlessRequestTypeDef",
-    {
-        "ClientAuthentication": "ServerlessClientAuthenticationTypeDef",
-    },
-    total=False,
-)
-
-
-class ServerlessRequestTypeDef(
-    _RequiredServerlessRequestTypeDef, _OptionalServerlessRequestTypeDef
-):
-    pass
-
 
 ServerlessSaslTypeDef = TypedDict(
     "ServerlessSaslTypeDef",
     {
-        "Iam": "IamTypeDef",
+        "Iam": NotRequired["IamTypeDef"],
     },
-    total=False,
 )
 
-_RequiredServerlessTypeDef = TypedDict(
-    "_RequiredServerlessTypeDef",
+ServerlessTypeDef = TypedDict(
+    "ServerlessTypeDef",
     {
         "VpcConfigs": List["VpcConfigTypeDef"],
+        "ClientAuthentication": NotRequired["ServerlessClientAuthenticationTypeDef"],
     },
 )
-_OptionalServerlessTypeDef = TypedDict(
-    "_OptionalServerlessTypeDef",
-    {
-        "ClientAuthentication": "ServerlessClientAuthenticationTypeDef",
-    },
-    total=False,
-)
-
-
-class ServerlessTypeDef(_RequiredServerlessTypeDef, _OptionalServerlessTypeDef):
-    pass
-
 
 StateInfoTypeDef = TypedDict(
     "StateInfoTypeDef",
     {
-        "Code": str,
-        "Message": str,
+        "Code": NotRequired[str],
+        "Message": NotRequired[str],
     },
-    total=False,
 )
 
 StorageInfoTypeDef = TypedDict(
     "StorageInfoTypeDef",
     {
-        "EbsStorageInfo": "EBSStorageInfoTypeDef",
+        "EbsStorageInfo": NotRequired["EBSStorageInfoTypeDef"],
     },
-    total=False,
 )
 
 TagResourceRequestRequestTypeDef = TypedDict(
@@ -1347,28 +1086,25 @@ TagResourceRequestRequestTypeDef = TypedDict(
 TlsTypeDef = TypedDict(
     "TlsTypeDef",
     {
-        "CertificateAuthorityArnList": Sequence[str],
-        "Enabled": bool,
+        "CertificateAuthorityArnList": NotRequired[Sequence[str]],
+        "Enabled": NotRequired[bool],
     },
-    total=False,
 )
 
 UnauthenticatedTypeDef = TypedDict(
     "UnauthenticatedTypeDef",
     {
-        "Enabled": bool,
+        "Enabled": NotRequired[bool],
     },
-    total=False,
 )
 
 UnprocessedScramSecretTypeDef = TypedDict(
     "UnprocessedScramSecretTypeDef",
     {
-        "ErrorCode": str,
-        "ErrorMessage": str,
-        "SecretArn": str,
+        "ErrorCode": NotRequired[str],
+        "ErrorMessage": NotRequired[str],
+        "SecretArn": NotRequired[str],
     },
-    total=False,
 )
 
 UntagResourceRequestRequestTypeDef = TypedDict(
@@ -1451,29 +1187,15 @@ UpdateClusterConfigurationResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateClusterKafkaVersionRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateClusterKafkaVersionRequestRequestTypeDef",
+UpdateClusterKafkaVersionRequestRequestTypeDef = TypedDict(
+    "UpdateClusterKafkaVersionRequestRequestTypeDef",
     {
         "ClusterArn": str,
         "CurrentVersion": str,
         "TargetKafkaVersion": str,
+        "ConfigurationInfo": NotRequired["ConfigurationInfoTypeDef"],
     },
 )
-_OptionalUpdateClusterKafkaVersionRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateClusterKafkaVersionRequestRequestTypeDef",
-    {
-        "ConfigurationInfo": "ConfigurationInfoTypeDef",
-    },
-    total=False,
-)
-
-
-class UpdateClusterKafkaVersionRequestRequestTypeDef(
-    _RequiredUpdateClusterKafkaVersionRequestRequestTypeDef,
-    _OptionalUpdateClusterKafkaVersionRequestRequestTypeDef,
-):
-    pass
-
 
 UpdateClusterKafkaVersionResponseTypeDef = TypedDict(
     "UpdateClusterKafkaVersionResponseTypeDef",
@@ -1484,28 +1206,14 @@ UpdateClusterKafkaVersionResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateConfigurationRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateConfigurationRequestRequestTypeDef",
+UpdateConfigurationRequestRequestTypeDef = TypedDict(
+    "UpdateConfigurationRequestRequestTypeDef",
     {
         "Arn": str,
         "ServerProperties": Union[bytes, IO[bytes], StreamingBody],
+        "Description": NotRequired[str],
     },
 )
-_OptionalUpdateConfigurationRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateConfigurationRequestRequestTypeDef",
-    {
-        "Description": str,
-    },
-    total=False,
-)
-
-
-class UpdateConfigurationRequestRequestTypeDef(
-    _RequiredUpdateConfigurationRequestRequestTypeDef,
-    _OptionalUpdateConfigurationRequestRequestTypeDef,
-):
-    pass
-
 
 UpdateConfigurationResponseTypeDef = TypedDict(
     "UpdateConfigurationResponseTypeDef",
@@ -1534,29 +1242,16 @@ UpdateConnectivityResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateMonitoringRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateMonitoringRequestRequestTypeDef",
+UpdateMonitoringRequestRequestTypeDef = TypedDict(
+    "UpdateMonitoringRequestRequestTypeDef",
     {
         "ClusterArn": str,
         "CurrentVersion": str,
+        "EnhancedMonitoring": NotRequired[EnhancedMonitoringType],
+        "OpenMonitoring": NotRequired["OpenMonitoringInfoTypeDef"],
+        "LoggingInfo": NotRequired["LoggingInfoTypeDef"],
     },
 )
-_OptionalUpdateMonitoringRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateMonitoringRequestRequestTypeDef",
-    {
-        "EnhancedMonitoring": EnhancedMonitoringType,
-        "OpenMonitoring": "OpenMonitoringInfoTypeDef",
-        "LoggingInfo": "LoggingInfoTypeDef",
-    },
-    total=False,
-)
-
-
-class UpdateMonitoringRequestRequestTypeDef(
-    _RequiredUpdateMonitoringRequestRequestTypeDef, _OptionalUpdateMonitoringRequestRequestTypeDef
-):
-    pass
-
 
 UpdateMonitoringResponseTypeDef = TypedDict(
     "UpdateMonitoringResponseTypeDef",
@@ -1567,28 +1262,15 @@ UpdateMonitoringResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateSecurityRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateSecurityRequestRequestTypeDef",
+UpdateSecurityRequestRequestTypeDef = TypedDict(
+    "UpdateSecurityRequestRequestTypeDef",
     {
         "ClusterArn": str,
         "CurrentVersion": str,
+        "ClientAuthentication": NotRequired["ClientAuthenticationTypeDef"],
+        "EncryptionInfo": NotRequired["EncryptionInfoTypeDef"],
     },
 )
-_OptionalUpdateSecurityRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateSecurityRequestRequestTypeDef",
-    {
-        "ClientAuthentication": "ClientAuthenticationTypeDef",
-        "EncryptionInfo": "EncryptionInfoTypeDef",
-    },
-    total=False,
-)
-
-
-class UpdateSecurityRequestRequestTypeDef(
-    _RequiredUpdateSecurityRequestRequestTypeDef, _OptionalUpdateSecurityRequestRequestTypeDef
-):
-    pass
-
 
 UpdateSecurityResponseTypeDef = TypedDict(
     "UpdateSecurityResponseTypeDef",
@@ -1599,33 +1281,21 @@ UpdateSecurityResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredVpcConfigTypeDef = TypedDict(
-    "_RequiredVpcConfigTypeDef",
+VpcConfigTypeDef = TypedDict(
+    "VpcConfigTypeDef",
     {
         "SubnetIds": Sequence[str],
+        "SecurityGroupIds": NotRequired[Sequence[str]],
     },
 )
-_OptionalVpcConfigTypeDef = TypedDict(
-    "_OptionalVpcConfigTypeDef",
-    {
-        "SecurityGroupIds": Sequence[str],
-    },
-    total=False,
-)
-
-
-class VpcConfigTypeDef(_RequiredVpcConfigTypeDef, _OptionalVpcConfigTypeDef):
-    pass
-
 
 ZookeeperNodeInfoTypeDef = TypedDict(
     "ZookeeperNodeInfoTypeDef",
     {
-        "AttachedENIId": str,
-        "ClientVpcIpAddress": str,
-        "Endpoints": List[str],
-        "ZookeeperId": float,
-        "ZookeeperVersion": str,
+        "AttachedENIId": NotRequired[str],
+        "ClientVpcIpAddress": NotRequired[str],
+        "Endpoints": NotRequired[List[str]],
+        "ZookeeperId": NotRequired[float],
+        "ZookeeperVersion": NotRequired[str],
     },
-    total=False,
 )
